# Core

```{eval-rst}
.. module:: annsel.core.expr
```

```{eval-rst}
.. currentmodule:: annsel
```

## Selectors and Expressions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/

   obs_names
   var_names
   col

```

## Types

```{eval-rst}
.. currentmodule:: annsel.core.typing
.. autosummary::
   :toctree: ../generated/

   Predicates
   IntoExpr
   SinglePredicate
   PredicatesCollection
```
